@@ -6,10 +6,6 @@ class Assortment(ObjectMS):
     def __init__(self, json):
         super().__init__(json)
 
-    @check_init
-    def get_id(self) -> str:
-        return self._json.get('id')
-
     @check_init
     def get_name(self) -> str:
         return self._json.get('name')
\ No newline at end of file
